@@ -95,17 +95,12 @@ class Track(core.Track):
             metadata,
         )
 
-        self.beats_path = core.none_path_join(
-            [self._data_home, self._track_paths["beat"][0]]
-        )
-        self.chords_path = os.path.join(self._data_home, self._track_paths["chords"][0])
-        self.keys_path = core.none_path_join(
-            [self._data_home, self._track_paths["keys"][0]]
-        )
-        self.sections_path = os.path.join(
-            self._data_home, self._track_paths["sections"][0]
-        )
-        self.audio_path = os.path.join(self._data_home, self._track_paths["audio"][0])
+        self.beats_path = self.get_path("beat")
+        self.chords_path = self.get_path("chords")
+        self.keys_path = self.get_path("keys")
+        self.sections_path = self.get_path("sections")
+
+        self.audio_path = self.get_path("audio")
 
         self.title = os.path.basename(self._track_paths["sections"][0]).split(".")[0]
 
