@@ -16,8 +16,11 @@ DATASETS = mirdata.DATASETS
 CUSTOM_TEST_TRACKS = {
     "beatles": "0111",
     "cante100": "008",
+    "compmusic_jingju_acappella": "lseh-Tan_Yang_jia-Hong_yang_dong-qm",
+    "compmusic_otmm_makam": "cafcdeaf-e966-4ff0-84fb-f660d2b68365",
     "giantsteps_key": "3",
     "dali": "4b196e6c99574dd49ad00d56e132712b",
+    "freesound_one_shot_percussive_sounds": "183",
     "giantsteps_tempo": "113",
     "gtzan_genre": "country.00000",
     "guitarset": "03_BN3-119-G_solo",
@@ -32,6 +35,8 @@ CUSTOM_TEST_TRACKS = {
     "saraga_carnatic": "116_Bhuvini_Dasudane",
     "saraga_hindustani": "59_Bairagi",
     "tinysol": "Fl-ord-C4-mf-N-T14d",
+    "dagstuhl_choirset": "DCS_LI_QuartetB_Take04_B2",
+    "tonas": "01-D_AMairena",
 }
 
 REMOTE_DATASETS = {
@@ -373,7 +378,7 @@ def test_load_methods():
             method_name = load_method.__name__
 
             # skip default methods
-            if method_name == "load_tracks":
+            if method_name == "load_tracks" or method_name == "load_multitracks":
                 continue
 
             # skip overrides, add to the SKIP dictionary to skip a specific load method
